@@ -3,23 +3,20 @@ use warnings FATAL => 'all';
 
 package Apache::SWIT::Maker::GeneratorsQueue;
 use base 'Class::Accessor';
-__PACKAGE__->mk_accessors(qw(tree generators));
+__PACKAGE__->mk_accessors(qw(generators));
 
 sub new {
 	my ($class, $args) = @_;
-	goto OUT if ($args && $args->{tree});
-
-	my $tree = YAML::LoadFile('conf/swit.yaml') 
-				or die "No conf/swit.yaml found";
+	my $tree = Apache::SWIT::Maker::Config->instance;
 	my $gclasses = $args->{generator_classes} ? 
 			$args->{generator_classes} : $tree->{generators};
 	my @gens;
 	for my $c (@$gclasses) {
 		eval "use $c";
 		die "Unable to use $c : $@" if $@;
-		push @gens, $c->new({ tree => $tree });
+		push @gens, $c->new;
 	}
-	$args = { tree => $tree, generators => \@gens };
+	$args = { generators => \@gens };
 OUT:	
 	return $class->SUPER::new($args);
 }
